@@ -1442,7 +1442,7 @@ void KviIrcSocket::readData(int)
 /*
 void KviIrcSocket::processData(char * buffer,int)
 {
-	register char *p=buffer;
+	char *p=buffer;
 	char *beginOfCurData = buffer;
 	int   bufLen = 0;
 	char *messageBuffer = (char *)kvi_malloc(1);
