@@ -470,7 +470,7 @@ void KviServerParser::encodeCtcpParameter(const char * parametr,TQString &result
 	// subset of rules and places it in the supplied buffer
 	//
 	KviTQCString buffer;
-	register const char* param=parametr;
+	const char* param=parametr;
 	if(!param)
 	{
 		if(bSpaceBreaks)
@@ -735,7 +735,7 @@ const char * KviServerParser::extractCtcpParameter(const char * p_msg_ptr,TQStri
 	//
     
 	KviTQCString buffer;
-	register const char* msg_ptr=p_msg_ptr;
+	const char* msg_ptr=p_msg_ptr;
 	int bInString = 0;
 	if(!msg_ptr) return 0;
 	while(*msg_ptr == ' ')msg_ptr++; // skip leading spaces
