@@ -74,7 +74,7 @@ static TQColor g_clrFind(0,0,0);
 
 static TQFont g_fntNormal("Courier New",8);
 
-KviCompletionBox::KviCompletionBox(TQWidget * parent = 0)
+KviCompletionBox::KviCompletionBox(TQWidget * parent)
 : KviTalListBox(parent)
 {
 	setPaletteForegroundColor(TQColor(0,0,0));
