@@ -277,7 +277,7 @@
 			setLastError(__tr("The message is not a hexadecimal string: this is not my stuff"));
 			return false;
 		} else {
-			if(len > 0)
+			if(*len > 0)
 			{
 				*outBuffer = (char *)kvi_malloc(*len);
 				kvi_memmove(*outBuffer,tmpBuf,*len);
@@ -303,7 +303,7 @@
 			setLastError(__tr("The message is not a base64 string: this is not my stuff"));
 			return false;
 		} else {
-			if(len > 0)
+			if(*len > 0)
 			{
 				*outBuffer = (char *)kvi_malloc(*len);
 				kvi_memmove(*outBuffer,tmpBuf,*len);
