@@ -504,7 +504,7 @@ KviSetupWizard::KviSetupWizard()
 	m_pCreateUrlHandlers = new TQCheckBox(__tr2qs("Make KVIrc default IRC client"),m_pDesktopIntegration->m_pVBox);
 	m_pCreateUrlHandlers->setChecked(true);
 #endif
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	m_pCreateDesktopShortcut = new TQCheckBox(__tr2qs("Create desktop shortcut"),m_pDesktopIntegration->m_pVBox);
 	m_pCreateDesktopShortcut->setChecked(true);
 #endif
@@ -845,7 +845,7 @@ void KviSetupWizard::makeLink()
 	CoUninitialize();
 #endif //COMPILE_ON_WINDOWS
 
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 	TQString tmp = TQDir::homeDirPath();
 	KviTQString::ensureLastCharIs(tmp,KVI_PATH_SEPARATOR_CHAR);
 	tmp.append("Desktop");
@@ -861,10 +861,10 @@ void KviSetupWizard::makeLink()
 		"Name=KVIrc 3\n" \
 		"Terminal=false\n" \
 		"Type=Application\n" \
-		"X-KDE-SubstituteUID=false\n";
+		"X-TDE-SubstituteUID=false\n";
 
 	KviFileUtils::writeFile(tmp,contents,false);
-#endif //COMPILE_KDE_SUPPORT
+#endif //COMPILE_TDE_SUPPORT
 
 }
 
@@ -1010,7 +1010,7 @@ void KviSetupWizard::accept()
 		symlink(TQTextCodec::codecForLocale()->fromUnicode(g_pApp->m_szGlobalKvircDir).data(),TQTextCodec::codecForLocale()->fromUnicode(localPath).data());
 #endif
 	
-#ifdef COMPILE_KDE_SUPPORT
+#ifdef COMPILE_TDE_SUPPORT
 		if(m_pCreateDesktopShortcut->isChecked())
 			makeLink();
 #endif
